@@ -100,6 +100,9 @@ class pyproxmox:
         elif conn_type == "get":
             pass
 
+        if conn_type is not "get":
+            self.c.setopt(pycurl.HTTPHEADER, ['CSRFPreventionToken:'+str(self.CSRF)])
+
         if post_data is not None:
             post_data = urllib.urlencode(post_data)
             self.c.setopt(pycurl.POSTFIELDS, post_data)
